function callback(name, data) {
    if (!data) data = '';
    window.location.href = 'skp:' + name + '@' + data;
}


function init() {
    var w = $( window ).width();
    var h = $( window ).height();
    var data = '['+w+','+h+']';
    callback('init', data);
}


function get_open_sections() {
    var data = '';
    $( '.collapsible' ).each( function(index) {
        if ($( this ).hasClass('collapse-open')) {
            data += ',' + this.id;
        }
    });
    return data.substring(1);
}


function set_open_sections(opts) {
    var sections = opts.split(',');
    $( '.collapsible' ).each( function() {
        if (jQuery.inArray( this.id, sections ) == -1) {
            $( this ).collapsible('loadClose');
        } else {
            $( this ).collapsible('loadOpen');
        }
    });
}


function adjust_size() {
    var w = 256 //$( '.collapsible' ).width() + 20;
    var h = $( 'body' ).height();
    var data = '['+w+','+h+']';
    callback('adjust_size', data);
}


function drag_start() {
    callback('drag_start', null);
}


function drag(dx,dy) {
    var data = '['+dx+','+dy+']';
    callback('drag', data);
}


function drag_end() {
    callback('drag_end', null);
}


function collapsible_changed() {
    var data = get_open_sections();
    callback('collapsible_changed', data);
}


function input_changed(id, val) {
    var data = '['+':'+ id+','+val+']';
    callback('input_changed', data);
}


function caption_changed(element) {
   var str = element.value.replace(/"|'|\\|\n|\r|^\s+|\s+$/g, '');
   element.value = str;
   callback('caption_changed', str);
}


function button_clicked(id) {
    callback('button_clicked', id);
}


function select_changed() {
    var val = document.getElementById('sel1').value;
    callback('select_changed', val);
}


$(document).ready( function() {
    // Initialize
    window.setTimeout(init, 0);

    // Collapsible management
    $.fn.slideFadeToggle = function(speed, easing, callback) {
        return this.animate({opacity: 'toggle', height: 'toggle'}, speed, easing, callback);
    };
    $( '.collapsible' ).collapsible({
        defaultOpen: '',
        speed: 'normal',
        bind: 'click',
        animateOpen: function (elem, opts) {
            elem.next().slideFadeToggle(opts.speed);
            collapsible_changed();
        },
        animateClose: function (elem, opts) {
            elem.next().slideFadeToggle(opts.speed);
            collapsible_changed();
        },
        loadOpen: function (elem) {
            elem.next().show();
        },
        loadClose: function (elem, opts) {
            elem.next().hide();
        }
    });

    // Adjust size
    jQuery.resize.delay = 10;
    $( 'body' ).resize( function() {
        setTimeout(adjust_size, 0);
    });

    // Detect Drag
    var md = false;
    var pos = [0,0];
    $( '.collapsible' ).mousedown(function(e) {
        md = true;
        var x = e.clientX;
        var y = e.clientY;
        pos = [x,y];
        drag_start();
    });
    $(document).mousemove(function(e) {
        if (!md) return;
        var x = e.clientX;
        var y = e.clientY;
        var dx = x-pos[0];
        var dy = y-pos[1];
        if ((dx == 0) && (dy == 0)) return;
        drag(dx,dy);
    });
    $(document).mouseup(function(e) {
        if (md) {
            md = false;
            drag_end();
        }
    });

    // Process checkbox and radio input triggers.
    $( 'input[type=checkbox], input[type=radio]' ).change( function() {
        input_changed(this.id, this.checked);
    });

    // Process text 1 input
    $( '#txt1' ).keydown( function(e) {
        e = e || window.event;
        var k = e.charCode || e.keyCode || 0;
        if (k == 13) caption_changed(this);
        return true;
    });
    $( '#txt1' ).change( function() {
        caption_changed(this);
    });

    // Process button clicks
    $( 'button' ).click( function() {
        if (this.name == 'submit') {
            shortcut_changed();
        } else {
            button_clicked(this.name);
        }
    });
});
